**Example 1: 请求示例**



Input: 

```
tccli live DeleteLiveSnapshotTemplate --cli-unfold-argument  \
    --TemplateId 1000
```

Output: 
```
{
    "Response": {
        "RequestId": "3c140219-cfe9-470e-b241-907877d6fb03"
    }
}
```

